## SCUF

**SCUF** (Spheroid Consensus Undeterministic Fitting) is an open-source implementation of the RANSAC (Random Sample Consensus) method, designed specifically for fitting ellipsoids in point clouds. It is a powerful tool for applications requiring precise detection of ellipsoidal shapes, such as object modeling, geometric analysis, and computer vision tasks. SCUF extends the classic RANSAC approach, offering specialized functionality for ellipsoid fitting.

## Installation
Requirements: Numpy, open3d

Install with [Pypi](https://pypi.org/project/scuf/):

```sh
pip3 install scuf
```
installation with 3D visualization capability (needed for demo)
```sh
pip install scuf[visualization]
```

## Take a look: 
For more details, visit the [GitHub repository](https://github.com/aidagroup/SCUF/).


## License
[MIT](https://github.com/aidagroup/SCUF/blob/main/LICENSE)
